<h1 align="center"> 
  <img src="https://raw.githubusercontent.com/DrSolidDevil/mlr-gd/main/logo.png" width="300">
  <br>
</h1>

Multiple linear regression by gradient descent.
<br><br>
<h4>Disclaimer:</h4>
This code is very early on and my first proper attempt to create a package so things may be a bit weird/not up to standard.


